# Simpol
This is a simpol package that does simple things more effieciently, basically if tyou wanted to add
something it would take you about 3 lines, this makes it into 2 lines, not THAT COOL, but overtime
this package will make your life much more easier as I add more packages.